==> haskell-hxt-9.3.1.16-3-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hxt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt
version: 9.3.1.16
id: hxt-9.3.1.16-YawaVI4czs2GYj8uhLpnV
key: hxt-9.3.1.16-YawaVI4czs2GYj8uhLpnV
license: MIT
copyright: Copyright (c) 2005-20161 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: A collection of tools for processing XML with Haskell.
description:
    The Haskell XML Toolbox bases on the ideas of HaXml and HXML,
    but introduces a more general approach for processing XML with Haskell.
    The Haskell XML Toolbox uses a generic data model for representing XML documents,
    including the DTD subset and the document subset, in Haskell.
    It contains a validating XML parser, a HTML parser, namespace support,
    an XPath expression evaluator, an XSLT library, a RelaxNG schema validator
    and funtions for serialization and deserialization of user defined data.
    The library makes extensive use of the arrow approach for processing XML.
    Since version 9 the toolbox is partitioned into various (sub-)packages.
    This package contains the core functionality,
    hxt-curl, hxt-tagsoup, hxt-relaxng, hxt-xpath, hxt-xslt,
    hxt-regex-xmlschema contain the extensions.
    hxt-unicode contains encoding and decoding functions,
    hxt-charproperties char properties for unicode and XML.
    .
    Changes from 9.3.1.15: Bug in quoting PI instructions in showXmlTrees fixed
    .
    Changes from 9.3.1.14: For ghc-7.10 network-uri is automatically selected
    .
    Changes from 9.3.1.13: ghc-7.10 compatibility
    .
    Changes from 9.3.1.12: Bug when unpickling an empty attribute value removed
    .
    Changes from 9.3.1.11: Bug fix in haddock comments
    .
    Changes from 9.3.1.10: Bug in DTD validation, space and time leak in delta removed
    .
    Changes from 9.3.1.9: lower bound of mtl dependency lowered to 2.0.1
    .
    Changes from 9.3.1.8: Bug in hread removed
    .
    Changes from 9.3.1.7: Foldable and Traversable instances for NTree added
    Control.Except used instead of deprecated Control.Error
    .
    Changes from 9.3.1.6: canonicalize added in hread and hreadDoc
    .
    Changes from 9.3.1.4: conditionally (no default)
    dependency from networt changed to network-uri with flag "network-uri"
    .
    Changes from 9.3.1.3: warnings from ghc-7.8.1 removed
    .
    Changes from 9.3.1.2: https as protocol added
    .
    Changes from 9.3.1.1: new parser xreadDoc
    .
    Changes from 9.3.1.0: in readString all input decoding switched off
    .
    Changes from 9.3.0.1: lower bound for network set to be >= 2.4
    .
    Changes from 9.3.0: upper bound for network set to be < 2.4
    (URI signatures changed in 2.4)
    .
    Changes from 9.2.2: XMLSchema validation integrated
    .
    Changes from 9.2.1: user defined mime type handlers added
    .
    Changes from 9.2.0: New warnings from ghc-7.4 removed
category: XML
author: Uwe Schmidt, Martin Schmidt, Torben Kuseler
exposed: True
exposed-modules:
    Control.Arrow.ArrowExc Control.Arrow.ArrowIO Control.Arrow.ArrowIf
    Control.Arrow.ArrowList Control.Arrow.ArrowNF
    Control.Arrow.ArrowNavigatableTree Control.Arrow.ArrowState
    Control.Arrow.ArrowTree Control.Arrow.IOListArrow
    Control.Arrow.IOStateListArrow Control.Arrow.ListArrow
    Control.Arrow.ListArrows Control.Arrow.NTreeEdit
    Control.Arrow.StateListArrow Control.FlatSeq Data.AssocList
    Data.Atom Data.Function.Selector Data.Tree.Class
    Data.Tree.NTree.TypeDefs Data.Tree.NTree.Edit
    Data.Tree.NTree.Zipper.TypeDefs Data.Tree.NavigatableTree.Class
    Data.Tree.NavigatableTree.XPathAxis Text.XML.HXT.Arrow.Binary
    Text.XML.HXT.Arrow.DTDProcessing Text.XML.HXT.Arrow.DocumentInput
    Text.XML.HXT.Arrow.DocumentOutput Text.XML.HXT.Arrow.Edit
    Text.XML.HXT.Arrow.GeneralEntitySubstitution
    Text.XML.HXT.Arrow.Namespace Text.XML.HXT.Arrow.ParserInterface
    Text.XML.HXT.Arrow.Pickle Text.XML.HXT.Arrow.Pickle.DTD
    Text.XML.HXT.Arrow.Pickle.Schema Text.XML.HXT.Arrow.Pickle.Xml
    Text.XML.HXT.Arrow.ProcessDocument Text.XML.HXT.Arrow.ReadDocument
    Text.XML.HXT.Arrow.WriteDocument Text.XML.HXT.Arrow.XmlArrow
    Text.XML.HXT.Arrow.XmlOptions Text.XML.HXT.Arrow.XmlRegex
    Text.XML.HXT.Arrow.XmlState
    Text.XML.HXT.Arrow.XmlState.ErrorHandling
    Text.XML.HXT.Arrow.XmlState.MimeTypeTable
    Text.XML.HXT.Arrow.XmlState.RunIOStateArrow
    Text.XML.HXT.Arrow.XmlState.TraceHandling
    Text.XML.HXT.Arrow.XmlState.TypeDefs
    Text.XML.HXT.Arrow.XmlState.URIHandling
    Text.XML.HXT.Arrow.XmlState.SystemConfig Text.XML.HXT.Core
    Text.XML.HXT.DOM.FormatXmlTree Text.XML.HXT.DOM.Interface
    Text.XML.HXT.DOM.MimeTypeDefaults Text.XML.HXT.DOM.MimeTypes
    Text.XML.HXT.DOM.QualifiedName Text.XML.HXT.DOM.ShowXml
    Text.XML.HXT.DOM.TypeDefs Text.XML.HXT.DOM.Util
    Text.XML.HXT.DOM.XmlKeywords Text.XML.HXT.DOM.XmlNode
    Text.XML.HXT.DTDValidation.AttributeValueValidation
    Text.XML.HXT.DTDValidation.DTDValidation
    Text.XML.HXT.DTDValidation.DocTransformation
    Text.XML.HXT.DTDValidation.DocValidation
    Text.XML.HXT.DTDValidation.IdValidation
    Text.XML.HXT.DTDValidation.RE Text.XML.HXT.DTDValidation.TypeDefs
    Text.XML.HXT.DTDValidation.Validation
    Text.XML.HXT.DTDValidation.XmlRE Text.XML.HXT.IO.GetFILE
    Text.XML.HXT.Parser.HtmlParsec
    Text.XML.HXT.Parser.ProtocolHandlerUtil
    Text.XML.HXT.Parser.XhtmlEntities Text.XML.HXT.Parser.XmlCharParser
    Text.XML.HXT.Parser.XmlDTDParser
    Text.XML.HXT.Parser.XmlDTDTokenParser
    Text.XML.HXT.Parser.XmlEntities Text.XML.HXT.Parser.XmlParsec
    Text.XML.HXT.Parser.XmlTokenParser
    Text.XML.HXT.XMLSchema.DataTypeLibW3CNames Text.XML.HXT.Version
abi: 482baeda6d3ed6bb7b6eb35356e853ea
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hxt-9.3.1.16
library-dirs: /usr/lib/ghc-8.0.2/site-local/hxt-9.3.1.16
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/hxt-9.3.1.16
hs-libraries: HShxt-9.3.1.16-YawaVI4czs2GYj8uhLpnV
depends:
    base-4.9.1.0 binary-0.8.3.0 bytestring-0.10.8.1 containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.3.0.0 filepath-1.4.1.1
    hxt-charproperties-9.2.0.1-48OogeCJMUc1lcYcm9OQtr
    hxt-regex-xmlschema-9.2.0.3-EJ79sDbAiO4CJ0CjtkP17K
    hxt-unicode-9.0.2.4-91NbsYmAW3YHFFSyOss7u4
    mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    parsec-3.1.11-1CA7c0vSU7tJHGhveOjoXR
haddock-interfaces: /usr/share/doc/haskell-hxt/html/hxt.haddock
haddock-html: /usr/share/doc/haskell-hxt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hxt-9.3.1.16-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hxt.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hxt
version: 9.3.1.16
id: hxt-9.3.1.16-1PYbpy4CWzMJMO0SpKBmK8
key: hxt-9.3.1.16-1PYbpy4CWzMJMO0SpKBmK8
license: MIT
copyright: Copyright (c) 2005-20161 Uwe Schmidt
maintainer: Uwe Schmidt <uwe@fh-wedel.de>
stability: Stable
homepage: https://github.com/UweSchmidt/hxt
synopsis: A collection of tools for processing XML with Haskell.
description:
    The Haskell XML Toolbox bases on the ideas of HaXml and HXML,
    but introduces a more general approach for processing XML with Haskell.
    The Haskell XML Toolbox uses a generic data model for representing XML documents,
    including the DTD subset and the document subset, in Haskell.
    It contains a validating XML parser, a HTML parser, namespace support,
    an XPath expression evaluator, an XSLT library, a RelaxNG schema validator
    and funtions for serialization and deserialization of user defined data.
    The library makes extensive use of the arrow approach for processing XML.
    Since version 9 the toolbox is partitioned into various (sub-)packages.
    This package contains the core functionality,
    hxt-curl, hxt-tagsoup, hxt-relaxng, hxt-xpath, hxt-xslt,
    hxt-regex-xmlschema contain the extensions.
    hxt-unicode contains encoding and decoding functions,
    hxt-charproperties char properties for unicode and XML.
    .
    Changes from 9.3.1.15: Bug in quoting PI instructions in showXmlTrees fixed
    .
    Changes from 9.3.1.14: For ghc-7.10 network-uri is automatically selected
    .
    Changes from 9.3.1.13: ghc-7.10 compatibility
    .
    Changes from 9.3.1.12: Bug when unpickling an empty attribute value removed
    .
    Changes from 9.3.1.11: Bug fix in haddock comments
    .
    Changes from 9.3.1.10: Bug in DTD validation, space and time leak in delta removed
    .
    Changes from 9.3.1.9: lower bound of mtl dependency lowered to 2.0.1
    .
    Changes from 9.3.1.8: Bug in hread removed
    .
    Changes from 9.3.1.7: Foldable and Traversable instances for NTree added
    Control.Except used instead of deprecated Control.Error
    .
    Changes from 9.3.1.6: canonicalize added in hread and hreadDoc
    .
    Changes from 9.3.1.4: conditionally (no default)
    dependency from networt changed to network-uri with flag "network-uri"
    .
    Changes from 9.3.1.3: warnings from ghc-7.8.1 removed
    .
    Changes from 9.3.1.2: https as protocol added
    .
    Changes from 9.3.1.1: new parser xreadDoc
    .
    Changes from 9.3.1.0: in readString all input decoding switched off
    .
    Changes from 9.3.0.1: lower bound for network set to be >= 2.4
    .
    Changes from 9.3.0: upper bound for network set to be < 2.4
    (URI signatures changed in 2.4)
    .
    Changes from 9.2.2: XMLSchema validation integrated
    .
    Changes from 9.2.1: user defined mime type handlers added
    .
    Changes from 9.2.0: New warnings from ghc-7.4 removed
category: XML
author: Uwe Schmidt, Martin Schmidt, Torben Kuseler
exposed: True
indefinite: False
exposed-modules:
    Control.Arrow.ArrowExc Control.Arrow.ArrowIO Control.Arrow.ArrowIf
    Control.Arrow.ArrowList Control.Arrow.ArrowNF
    Control.Arrow.ArrowNavigatableTree Control.Arrow.ArrowState
    Control.Arrow.ArrowTree Control.Arrow.IOListArrow
    Control.Arrow.IOStateListArrow Control.Arrow.ListArrow
    Control.Arrow.ListArrows Control.Arrow.NTreeEdit
    Control.Arrow.StateListArrow Control.FlatSeq Data.AssocList
    Data.Atom Data.Function.Selector Data.Tree.Class
    Data.Tree.NTree.Edit Data.Tree.NTree.TypeDefs
    Data.Tree.NTree.Zipper.TypeDefs Data.Tree.NavigatableTree.Class
    Data.Tree.NavigatableTree.XPathAxis Text.XML.HXT.Arrow.Binary
    Text.XML.HXT.Arrow.DTDProcessing Text.XML.HXT.Arrow.DocumentInput
    Text.XML.HXT.Arrow.DocumentOutput Text.XML.HXT.Arrow.Edit
    Text.XML.HXT.Arrow.GeneralEntitySubstitution
    Text.XML.HXT.Arrow.Namespace Text.XML.HXT.Arrow.ParserInterface
    Text.XML.HXT.Arrow.Pickle Text.XML.HXT.Arrow.Pickle.DTD
    Text.XML.HXT.Arrow.Pickle.Schema Text.XML.HXT.Arrow.Pickle.Xml
    Text.XML.HXT.Arrow.ProcessDocument Text.XML.HXT.Arrow.ReadDocument
    Text.XML.HXT.Arrow.WriteDocument Text.XML.HXT.Arrow.XmlArrow
    Text.XML.HXT.Arrow.XmlOptions Text.XML.HXT.Arrow.XmlRegex
    Text.XML.HXT.Arrow.XmlState
    Text.XML.HXT.Arrow.XmlState.ErrorHandling
    Text.XML.HXT.Arrow.XmlState.MimeTypeTable
    Text.XML.HXT.Arrow.XmlState.RunIOStateArrow
    Text.XML.HXT.Arrow.XmlState.SystemConfig
    Text.XML.HXT.Arrow.XmlState.TraceHandling
    Text.XML.HXT.Arrow.XmlState.TypeDefs
    Text.XML.HXT.Arrow.XmlState.URIHandling Text.XML.HXT.Core
    Text.XML.HXT.DOM.FormatXmlTree Text.XML.HXT.DOM.Interface
    Text.XML.HXT.DOM.MimeTypeDefaults Text.XML.HXT.DOM.MimeTypes
    Text.XML.HXT.DOM.QualifiedName Text.XML.HXT.DOM.ShowXml
    Text.XML.HXT.DOM.TypeDefs Text.XML.HXT.DOM.Util
    Text.XML.HXT.DOM.XmlKeywords Text.XML.HXT.DOM.XmlNode
    Text.XML.HXT.DTDValidation.AttributeValueValidation
    Text.XML.HXT.DTDValidation.DTDValidation
    Text.XML.HXT.DTDValidation.DocTransformation
    Text.XML.HXT.DTDValidation.DocValidation
    Text.XML.HXT.DTDValidation.IdValidation
    Text.XML.HXT.DTDValidation.RE Text.XML.HXT.DTDValidation.TypeDefs
    Text.XML.HXT.DTDValidation.Validation
    Text.XML.HXT.DTDValidation.XmlRE Text.XML.HXT.IO.GetFILE
    Text.XML.HXT.Parser.HtmlParsec
    Text.XML.HXT.Parser.ProtocolHandlerUtil
    Text.XML.HXT.Parser.XhtmlEntities Text.XML.HXT.Parser.XmlCharParser
    Text.XML.HXT.Parser.XmlDTDParser
    Text.XML.HXT.Parser.XmlDTDTokenParser
    Text.XML.HXT.Parser.XmlEntities Text.XML.HXT.Parser.XmlParsec
    Text.XML.HXT.Parser.XmlTokenParser Text.XML.HXT.Version
    Text.XML.HXT.XMLSchema.DataTypeLibW3CNames
abi: 48c7bfdc2ec8ea275b939da0d91b379c
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/hxt-9.3.1.16
library-dirs: /usr/lib/ghc-8.2.1/site-local/hxt-9.3.1.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/hxt-9.3.1.16
hs-libraries: HShxt-9.3.1.16-1PYbpy4CWzMJMO0SpKBmK8
depends:
    base-4.10.0.0 containers-0.5.10.2 directory-1.3.0.2
    filepath-1.4.1.2 parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh
    mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3 deepseq-1.4.3.0
    bytestring-0.10.8.2 binary-0.8.5.1
    hxt-charproperties-9.2.0.1-DwMBWjhyRF1Ll697rODxMh
    hxt-unicode-9.0.2.4-HrCDROnPAej3zADTzj2LSZ
    hxt-regex-xmlschema-9.2.0.3-6IRa3aSN1ndAszcsl00AVt
    network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             parsec-3.1.11-5WCVqUZr6ypLPXtYWYsMnh=da03630454c215de5f3965e7b0f0e5da
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             deepseq-1.4.3.0=ab64de23c9713e035549193002fe9df0
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             binary-0.8.5.1=b72be3099f9dcf7a652ee107dea27d54
             hxt-charproperties-9.2.0.1-DwMBWjhyRF1Ll697rODxMh=f123fbce30d0a477393b885fa468c37f
             hxt-unicode-9.0.2.4-HrCDROnPAej3zADTzj2LSZ=9d8af02717035a15677c8758b4f7327a
             hxt-regex-xmlschema-9.2.0.3-6IRa3aSN1ndAszcsl00AVt=efc3a8fdc66492dcd4cbf1d212554670
             network-uri-2.6.1.0-4GXMsZ4PWr49y3TK4YgSYK=dcf3b42c1c39d8e42cbbbf74ea3e6c8c
haddock-interfaces: /usr/share/doc/haskell-hxt/html/hxt.haddock
haddock-html: /usr/share/doc/haskell-hxt/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
